==> geopsypack-src-3.3.5.tar.gz: geopsypack-src-3.3.5/SciFigs/src/RealStatisticalLine.cpp <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2008-11-03
**  Copyright: 2008-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#include "RealStatisticalLine.h"
#include "LineFactory.h"

namespace SciFigs {

  /*!
    \class RealStatisticalLine RealStatisticalLine.h
    \brief Brief description of class still missing

    Full description of class still missing
  */

const QString RealStatisticalLine::xmlRealStatisticalLineTag="RealStatisticalLine";

REGISTER_LINE(RealStatisticalLine, "RealStatisticalLine" );
SYNONYM_LINE(StatLine, "RealStatisticalLine" )

AbstractLine * RealStatisticalLine::clone() const
{
  RealStatisticalLine * l=new RealStatisticalLine;
  *l=*this;
  return l;
}

void RealStatisticalLine::operator=(const RealStatisticalLine& o)
{
  _curve=o._curve;
  AbstractLine::operator=(o);
}

Point RealStatisticalLine::point(int index, const CurvePointOptions *) const
{
  TRACE;
  Point p;
  const RealStatisticalPoint& dp=_curve.at(index);
  p.setX(dp.x());
  p.setY(dp.mean());
  p.setZ(dp.stddev());
  return p;
}

} // namespace SciFigs

==> geopsypack-src-3.4.1.tar.gz: geopsypack-src-3.4.1/SciFigs/src/RealStatisticalLine.cpp <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2008-11-03
**  Copyright: 2008-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#include "RealStatisticalLine.h"
#include "LineFactory.h"

namespace SciFigs {

  /*!
    \class RealStatisticalLine RealStatisticalLine.h
    \brief Brief description of class still missing

    Full description of class still missing
  */

const QString RealStatisticalLine::xmlRealStatisticalLineTag="RealStatisticalLine";

REGISTER_LINE(RealStatisticalLine, "RealStatisticalLine" );
SYNONYM_LINE(StatLine, "RealStatisticalLine" )

AbstractLine * RealStatisticalLine::clone() const
{
  RealStatisticalLine * l=new RealStatisticalLine;
  *l=*this;
  return l;
}

void RealStatisticalLine::operator=(const RealStatisticalLine& o)
{
  _curve=o._curve;
  AbstractLine::operator=(o);
}

Point RealStatisticalLine::point(int index, const CurvePointOptions *) const
{
  TRACE;
  Point p;
  const RealStatisticalPoint& dp=_curve.constAt(index);
  p.setX(dp.x());
  p.setY(dp.mean());
  p.setZ(dp.stddev());
  return p;
}

} // namespace SciFigs
